package tcc.haruki.schnorr;
import java.security.NoSuchAlgorithmException;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;

import tcc.haruki.domain.xtr.XTRKey;
import tcc.haruki.domain.xtr.XTRParameters;
import tcc.haruki.exceptions.XTRInvalidParametersException;
import tcc.haruki.exceptions.XTRInvalidKeyException;
import tcc.haruki.exceptions.XTRNullKeyException;
import tcc.haruki.exceptions.XTRNullParametersException;
import tcc.haruki.schnorr.SchnorrXTRSignature;
import tcc.haruki.schnorr.exceptions.SchnorrException;
import tcc.haruki.services.XTROperationService;
import tcc.haruki.services.impl.XTRDefaultOperationService;


public class SchnorrTest {

	private XTRParameters params;
	private XTRKey key;
	private XTROperationService service;
	
	@Before
	public void setup() throws XTRNullParametersException, XTRInvalidParametersException, XTRInvalidKeyException {
		params = XTRParameters.generateParameters();
		service = new XTRDefaultOperationService(params);
		key = service.generateKeys();
	}
	
	
	@Test
	public void signAndVerifyTest() throws XTRNullKeyException, XTRInvalidKeyException, NoSuchAlgorithmException, XTRInvalidParametersException, SchnorrException, NullPointerException, XTRNullParametersException {
		SchnorrXTRSignature signature1 = SchnorrXTRSignature.initialize(key);
		SchnorrXTRSignature signature2 = SchnorrXTRSignature.initialize(key);
		
		byte[] msg = "Alo teste".getBytes();
		
		signature1.update(msg);
		signature1.startSigning();
		byte[] sign = signature1.sign();
		
		signature2.update(msg);
		signature2.startVerifying();
		Assert.assertEquals(true, signature2.verify(sign));
	}
}
